@@ -40,14 +40,18 @@ class MultiLabelLinearClsHead(MultiLabelClsHead):
         self.fc = nn.Linear(self.in_channels, self.num_classes)
 
     def forward_train(self, x, gt_label):
+        if isinstance(x, tuple):
+            x = x[-1]
         gt_label = gt_label.type_as(x)
         cls_score = self.fc(x)
         losses = self.loss(cls_score, gt_label)
         return losses
 
-    def simple_test(self, img):
+    def simple_test(self, x):
         """Test without augmentation."""
-        cls_score = self.fc(img)
+        if isinstance(x, tuple):
+            x = x[-1]
+        cls_score = self.fc(x)
         if isinstance(cls_score, list):
             cls_score = sum(cls_score) / float(len(cls_score))
         pred = F.sigmoid(cls_score) if cls_score is not None else None
